@@ -3,18 +3,17 @@ from __future__ import unicode_literals
 
 def push(
     self,
-    target=None,
+    targets=None,
     jobs=None,
     remote=None,
     all_branches=False,
-    show_checksums=False,
     with_deps=False,
     all_tags=False,
     recursive=False,
 ):
     with self.state:
         used = self.used_cache(
-            target,
+            targets,
             all_branches=all_branches,
             all_tags=all_tags,
             with_deps=with_deps,
@@ -23,6 +22,4 @@ def push(
             jobs=jobs,
             recursive=recursive,
         )["local"]
-        return self.cloud.push(
-            used, jobs, remote=remote, show_checksums=show_checksums
-        )
+        return self.cloud.push(used, jobs, remote=remote)
